pub enum ResamplerError {
InvalidFormat {
format: AudioFormat,
},
MisalignedSamples {
samples: usize,
channels: u16,
},
Resampling(String),
}Expand description
Why an audio chunk could not be converted by a Resampler.
Variants
InvalidFormat
A sample rate or channel count was zero.
Fields

format: AudioFormatThe unusable format.
MisalignedSamples
An interleaved buffer did not contain whole audio frames.
Fields
Resampling(String)
A resampling implementation rejected an operation.